==> qtools_profiler-2.2.x-dev.tar.gz: qtools_profiler/src/Cache/ProfilerPreviewAccessContext.php <==
<?php

namespace Drupal\qtools_profiler\Cache;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Cache\Context\CacheContextInterface;
use Drupal\qtools_profiler\Access\ProfilerPreviewAccessCheck;
use Symfony\Component\DependencyInjection\ContainerAwareInterface;
use Symfony\Component\DependencyInjection\ContainerAwareTrait;

/**
 * Defines cache context if cache profiler preview is accessible or not.
 */
class ProfilerPreviewAccessContext implements CacheContextInterface, ContainerAwareInterface {

  // Cache contexts.
  const CACHE_CONTEXT_KEY = 'qtools_profiler_preview_access';

  use ContainerAwareTrait;

  /**
   * Drupal\qtools_profiler\Access\ProfilerPreviewAccessCheck.
   *
   * @var \Drupal\qtools_profiler\Access\ProfilerPreviewAccessCheck
   */
  protected $profilerPreviewAccessCheck;

  /**
   * Constructs a new CustomerCanOrderContext service.
   */
  public function __construct(ProfilerPreviewAccessCheck $profilerPreviewAccessCheck) {
    $this->profilerPreviewAccessCheck = $profilerPreviewAccessCheck;
  }

  /**
   * {@inheritdoc}
   */
  public static function getLabel() {
    return t("Profiler preview accessible.");
  }

  /**
   * {@inheritdoc}
   */
  public function getContext() {
    /** @var \Drupal\Core\Session\AccountProxyInterface $current_user */
    $current_user = $this->container->get('current_user');
    $access = $this->profilerPreviewAccessCheck->access($current_user);
    return $access->isAllowed() ? '1' : '0';
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata() {
    return new CacheableMetadata();
  }

}

==> qtools_profiler-2.3.x-dev.tar.gz: qtools_profiler/src/Cache/ProfilerPreviewAccessContext.php <==
<?php

namespace Drupal\qtools_profiler\Cache;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Cache\Context\CacheContextInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\qtools_profiler\Access\ProfilerPreviewAccessCheck;
use Symfony\Component\DependencyInjection\ContainerAwareInterface;
use Symfony\Component\DependencyInjection\ContainerAwareTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines cache context if cache profiler preview is accessible or not.
 */
class ProfilerPreviewAccessContext implements CacheContextInterface, ContainerInjectionInterface {

  // Cache contexts.
  const CACHE_CONTEXT_KEY = 'qtools_profiler_preview_access';

  /**
   * Constructs a new CustomerCanOrderContext service.
   */
  public function __construct(
    protected ProfilerPreviewAccessCheck $profilerPreviewAccessCheck,
  ) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('access_check.qtools_profiler_preview'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public static function getLabel() {
    return t("Profiler preview accessible.");
  }

  /**
   * {@inheritdoc}
   */
  public function getContext() {
    /** @var \Drupal\Core\Session\AccountProxyInterface $current_user */
    $current_user = $this->container->get('current_user');
    $access = $this->profilerPreviewAccessCheck->access($current_user);
    return $access->isAllowed() ? '1' : '0';
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata() {
    return new CacheableMetadata();
  }

}
